@@ -4,10 +4,7 @@ package DateTimeX::Fiscal::Fiscal5253;
 
 use strict;
 
-our $VERSION = '1.01';
-
-# This enables trace messages to be used by the test suite.
-our $TRACE = 0;
+our $VERSION = '1.02';
 
 use Carp;
 use DateTime;
@@ -156,8 +153,6 @@ my $_build_periods = sub {
     # methods such as "contains" in normal years.
     # return if ($restate || $truncate) && $self->{_weeks} == 52;
 
-    carp "Data for a $style calendar will be generated\n" if $TRACE;
-
     my $pstart = $self->{_start}->clone;
 
     # This value is confusing only because it is 0-based unlike
@@ -237,8 +232,6 @@ my $_build_periods = sub {
         $self->{"_${style}_weeks"} = $wdata;
     }
 
-    $self->{_stale} = 0;
-
     return;
 };
 
@@ -347,7 +340,6 @@ sub new
 
     my $class = ref($proto) || $proto;
     my $self = bless {
-        _stale => 1,
         _style => 'fiscal',
         _fiscal => undef,
         _restated => undef,
@@ -532,7 +524,7 @@ sub contains
     }
     my $p = $whash->{$w}->{period};
 
-    return wantarray ? ( period => $p, week => $w ) : $p;
+    return wantarray ? ( period => $p, week => $w ) : $w;
 }
 
 # Utiliy routine, hidden from public use, to prevent duplicate code in
@@ -760,8 +752,8 @@ There are two legal values: "first" and "last". Default: "last"
 =back
 
 The last two parameters control what year the calendar is generated for.
-B<Note:> These parameters are optional but mutually exclusive and will
-throw an error if both are present.
+These parameters are optional but B<mutually exclusive> and will
+throw an exception if both are present.
 
 =over 4
 
@@ -779,7 +771,7 @@ B<NOTE!> In normal accounting terms, a fiscal year is named for the calendar
 year it ends in. That is, for a fiscal year that ends in October, fiscal year
 2005 would begin in October or November of calendar year 2004
 (depending upon the setting of C<end_type>.) However, Retail 4-5-4
-calendars are named for the year they B<begn> in. This means that a Retail
+calendars are named for the year they B<begin> in. This means that a Retail
 4-5-4 calendar for 2005 would begin in 2005 and not 2004 as an accountant
 would normally think. See the discussion at the end of this documentation
 about Retail 4-5-4 calendars for more information.
@@ -795,7 +787,7 @@ vs the fiscal year.
 If the value for C<date> is a string, it must be specified as either
 "YYYY-MM-DD" or "MM/DD/YYYY" or some reasonable variant of those such as
 single digit days and months. Time components, if present, are discarded.
-Any other format will generate a fatal error. A L<DateTime> object will be
+Any other format will throw an exception. A L<DateTime> object will be
 cloned before being used to prevent unwanted changes to the original object.
 
 =back
@@ -804,7 +796,7 @@ cloned before being used to prevent unwanted changes to the original object.
 
 The accessors allow you to examine the parameters used to create the calendar
 and the resulting base values. All accessors are read-only and will throw
-an exception if an attempt is made to change the value.
+an exception if a parameter is passed to them.
 
 If you want to change any of the underlying properties that define an
 object, B<create a new object!>
@@ -831,27 +823,28 @@ object, B<create a new object!>
 
 Returns the either the value that was supplied for the C<year> parameter to
 the constuctor or the year that resulted from the value supplied in the
-C<date> parameter. This is what would be used as the name of the fiscal year.
+constructor's C<date> parameter. This is what will be used as the name of
+the fiscal year.
 
 =head2 start
 
  my $start = $fc->start();
 
-Returns the first date in the fiscal year as contructed from the parameters
+Returns the first date in the fiscal year as constructed from the parameters
 given to the constructor.
 
 =head2 end
 
  my $end = $fc->end();
 
-Returns the last date in the fiscal year as contructed from the parameters
+Returns the last date in the fiscal year as constructed from the parameters
 given to the constructor.
 
 =head2 weeks
 
  my $weeks = $fc->weeks();
 
-Returns the number of weeks in the fiscal year as constructed by the
+Returns the number of weeks in the fiscal year as generated by the
 parameters given to the construtor. The value will be either "52" or "53"
 depending on whether a leap week was added. This value does B<not> look
 at the calendar style but rather is based on only the fiscal year itself.
@@ -903,7 +896,7 @@ year-over-year comparisons involving a year that would otherwise have
  my %summary = $fc->summary( style => 'restated');
  my $summary = $fc->summary( 'restated' );
 
-This method will return either a hash or a reference to a hash (denpending
+This method will return either a hash or a reference to a hash (depending
 upon context) containing a summary of the current calendar style or the one
 specified by the style parameter.
 
@@ -924,7 +917,8 @@ year as commonly used by accountants (as in "fye2012") and is usually the
 same as the calendar year the fiscal year B<ends> in. However, it is
 possible for the actual ending date to be in the B<following> calendar
 year when the C<end_month> is '12' (the default) and an C<end_type> of
-"closest" specified, fiscal year 2014 built as shown below demonstrates this:
+"closest" is specified, fiscal year 2014 built as shown below demonstrates
+this:
 
  my $fc = DateTimeX::Fiscal::Fiscal5253->new(
               year => 2014,
@@ -944,8 +938,8 @@ year when the C<end_month> is '12' (the default) and an C<end_type> of
 
  my $fc = DateTimeX::Fiscal::Fiscal5253->new( year => 2012 );
   
- if ( my $pnum = $fc->contains() ) {
-     print "The current date is in period $pnum\n";
+ if ( my $wnum = $fc->contains() ) {
+     print "The current date is in week $wnum\n";
  }
   
  if ( $fc->contains( date => 'today', style => 'restated' ) ) {
@@ -957,8 +951,8 @@ year when the C<end_month> is '12' (the default) and an C<end_type> of
  }
   
  my $dt = DateTime->today( time_zone => 'floating' );
- if ( my $pnum = $fc->contains( date => $dt ) ) {
-     print "$dt is in period $pnum\n";
+ if ( my $wnum = $fc->contains( date => $dt ) ) {
+     print "$dt is in weel $wnum\n";
  }
   
  my %containers = $fc->contains( '2012-06-04' );
@@ -968,9 +962,9 @@ year when the C<end_month> is '12' (the default) and an C<end_type> of
           'week' => 23
         };
 
-Returns the period in the designated style that contains the given date or
-'0' if not. The method will C<croak> if an error occurs such as an invalid date
-format or unknown style type.
+Returns the week number in the designated style that contains the given
+date or '0' if not. The method will C<croak> if an error occurs such as an
+invalid date format or unknown style type.
 
 This method takes two named parameters, 'date' and 'style'. Bear in mind
 that some dates that are in the fiscal calendar might not be in a restated
@@ -984,7 +978,7 @@ method is called in list context.
 
 =item C<date>
 
-Accepts the same formats as the contructor as well as the special
+Accepts the same formats as the constructor as well as the special
 keyword 'today'. Defaults to the current date if not supplied.
 
 =item C<style>
@@ -1008,9 +1002,8 @@ the specified style type.
 
 =item C<period>
 
-Must be a number in the range 1 - 12. If not given, the current date will
-used if it exists in the requested style and period data
-containing it will be returned.
+Must be a number in the range 1 - 12. An exception will be thrown if this
+parameter is not given.
 
 =item C<style>
 
@@ -1031,18 +1024,7 @@ The returned data is as follows:
           'end' => '2012-03-02'
         };
 
-B<Note!> It is an error condition to supply a value of C<undef> or '0' for
-'period'.  Consider what can happen if one is tempted to write code such
-as this:
-
- my $pinfo = $fc->period( period => $fc->contains( date => $somedate ) );
-
-This could produce unexpected results if C<$somedate> does not exist in the
-calendar. Without this restriction, the 'period' method would attempt
-to use the current date, which may or may not exist in the object, and would
-almost certainly be different than what was desired.
-
-The following methods are syntactic sugar for those who want to access the
+The following methods are syntactic sugar for those who prefer to access the
 individual components of the period structure without dealing with a hash.
 They return a scalar value and accept the same parameters as C<period> does.
 
@@ -1085,9 +1067,7 @@ the specified style type.
 =item C<week>
 
 Must be a number in the range 1 - 52 (53 if a leap week is present in the
-requested style.) If not given, the current date will used if it exists in
-the requested style and the data for the week data containing it will be
-returned.
+requested style.) An exception will be thrown if not given.
 
 =item C<style>
 
@@ -1108,10 +1088,7 @@ The returned data is as follows:
           'end' => '2012-02-04',
         };
 
-B<Note!> It is an error condition to supply a value of C<undef> or '0' for
-'week' for the same reason as given for C<period> above.
-
-The following methods are syntactic sugar for those who want to access the
+The following methods are syntactic sugar for those who prefer to access the
 individual components of the week structure without dealing with a hash.
 They return a scalar value and accept the same parameters as C<week> does.
 
